@@ -5,7 +5,7 @@ use Compress::Zlib;
 use Parse::CPAN::Packages::Distribution;
 use Parse::CPAN::Packages::Package;
 use version;
-our $VERSION = '2.32';
+our $VERSION = '2.33';
 
 has 'filename'    => ( is => 'rw', isa => 'Str' );
 has 'details'     => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
@@ -64,10 +64,9 @@ foreach my $subname (
 
 sub parse {
     my ( $self, $filename ) = @_;
-    my $details = $self->_slurp_details($filename);
 
     # read the preamble
-    my @details = split "\n", $details;
+    my @details = split "\n", $self->_slurp_details($filename);
     while (@details) {
         local $_ = shift @details;
         last if /^\s*$/;
@@ -312,12 +311,21 @@ file. You should do this yourself.  For example:
    my $data = get("http://www.cpan.org/modules/02packages.details.txt.gz");
    my $p = Parse::CPAN::Packages->new($data);
 
+If you have a configured L<CPAN>, then there's usually already a
+cached file available:
+
+   use CPAN;
+   $CPAN::Be_Silent = 1;
+   CPAN::HandleConfig->load;
+   my $file = $CPAN::Config->{keep_source_where} . "/modules/02packages.details.txt.gz";
+   my $p = Parse::CPAN::Packages->new($file);
+
 =item package($packagename)
 
 Returns a C<Parse::CPAN::Packages::Package> that represents the
 named package.
 
-  my $p = Parse::CPAN::Distribution->new($gzfilename);
+  my $p = Parse::CPAN::Packages->new($gzfilename);
   my $package = $p->package("Acme::Colour");
 
 =item packages()
@@ -327,20 +335,20 @@ representing all the packages that were extracted from the file.
 
 =item package_count()
 
-Returns the numebr of packages stored.
+Returns the number of packages stored.
 
 =item distribution($filename)
 
-Returns a B<Parse::CPAN::Distribution> that represents the
-filename passed:
+Returns a B<Parse::CPAN::Packages::Distribution> object that
+represents the filename passed:
 
-  my $p = Parse::CPAN::Distribution->new($gzfilename);
+  my $p = Parse::CPAN::Packages->new($gzfilename);
   my $dist = $p->distribution('L/LB/LBROCARD/Acme-Colour-1.00.tar.gz');
 
 =item distributions()
 
-Returns a list of B<Parse::CPAN::Distribution> objects representing
-all the known distributions.
+Returns a list of B<Parse::CPAN::Packages::Distribution> objects
+representing all the known distributions.
 
 =item distribution_count()
 
@@ -348,18 +356,19 @@ Returns the number of distributions stored.
 
 =item latest_distribution($distname)
 
-Returns the C<Parse::CPAN::Distribution> that represents the latest
-distribution for the named disribution passed, that is to say it
-returns the distribution that has the highest version number (as
-determined by version.pm or number comparison if that fails):
+Returns the C<Parse::CPAN::Packages::Distribution> object that
+represents the latest distribution for the named disribution passed,
+that is to say it returns the distribution that has the highest
+version number (as determined by version.pm or number comparison if
+that fails):
 
-  my $p = Parse::CPAN::Distribution->new($gzfilename);
+  my $p = Parse::CPAN::Packages->new($gzfilename);
   my $dist = $p->distribution('Acme-Color');
 
 =item latest_distrbutions()
 
-Returns a list of B<Parse::CPAN::Distribution> objects representing
-all the latest distributions.
+Returns a list of B<Parse::CPAN::Packages::Distribution> objects
+representing all the latest distributions.
 
 =item latest_distribution_count()
 
